uri_template: RFC 6570 URI Template Processor
=============================================

Description
-----------

RFC 6570 URI Template Processor

License
-------

MIT License

Upstream Contact
----------------

https://pypi.org/project/uri-template/

